pub fn codegen(opts: &CodegenOptions) -> Result<(), TbError>Expand description
Generates Rust source code from a specification file.
See CodegenOptions for more information about function parameters.
Examples
This example shows how the codegen function may be called directly. However, the recommended and a shorter way to invoke the function is using CodegenOptions::codegen method. See CodegenOptions for a full example.
let mut opts = CodegenOptions::new();
opts.spec("tighterror.yaml".to_owned());
codegen(&opts)?;